@@ -9,109 +9,155 @@
 # python3 confirm_debian_bugs.py same BV            -> found    | fixed
 # python3 confirm_debian_bugs.py new  BV            -> reassign | retitle
 
-from __future__ import print_function
+# flake8 confirm_debian_bugs.py
+# pylint confirm_debian_bugs.py
+# mypy confirm_debian_bugs.py
+# rm -fr .mypy_cache/
+
+# pylint: disable=too-many-lines
+# pylint: disable=missing-module-docstring
+# pylint: disable=missing-function-docstring
+
 import os.path
 import re
 import shutil
 import subprocess
 import sys
 import tempfile
+import typing
 
-os.environ ['LC_ALL'] = 'C'
+Make: typing.TypeAlias = typing.Sequence[str]
+Sources: typing.TypeAlias = typing.Iterable[tuple[str, str]]
 
-assert len (sys.argv) == 3
-assert sys.argv [1] in ("same", "new")
-same_gcc_base_version = sys.argv [1] == "same"
-new_version = sys.argv [2]
+os.environ['LC_ALL'] = 'C'
 
-for line in subprocess.check_output (("dpkg", "--status", "gnat-" + new_version)).decode ().split ("\n"):
-    if line.startswith ("Version: "):
-        deb_version = line [len ("Version: "):]
+assert len(sys.argv) == 3, 'expected same|new new_version'
+assert sys.argv[1] in ("same", "new")
+SAME_GCC_BASE_VERSION = sys.argv[1] == "same"
+new_version = sys.argv[2]
+
+for line in subprocess.check_output(
+        ("dpkg", "--status", f"gnat-{new_version}")).decode().split("\n"):
+    if line.startswith("Version: "):
+        deb_version = line[len("Version: "):]
         break
 # Will cause an error later if deb_version is not defined.
 
 # Each bug has its own subdirectory in WORKSPACE.
 # Every bug subdir is removed if the bug is confirmed,
 # and WORKSPACE is removed if empty.
-workspace = tempfile.mkdtemp (suffix = "-gnat-" + deb_version + "-bugs")
+workspace = tempfile.mkdtemp(suffix=f"-gnat-{new_version}-bugs")
 
-def attempt_to_reproduce (bug, make, sources):
-    tmp_dir = os.path.join (workspace, "bug{}".format (bug))
-    os.mkdir (tmp_dir)
+
+def attempt_to_reproduce(bug: int,
+                         make: Make,
+                         sources: Sources,
+                         ) -> tuple[str, int, str]:
+    tmp_dir = os.path.join(workspace, f"bug{bug}")
+    os.mkdir(tmp_dir)
 
     for (name, contents) in sources:
-        with open (os.path.join (tmp_dir, name), "w") as f:
-            f.write (contents)
+        with open(os.path.join(tmp_dir, name), "w", encoding="UTF-8") as out_f:
+            out_f.write(contents)
 
-    path = os.path.join (tmp_dir, "stderr.log")
-    with open (path, "w") as e:
-        status = subprocess.call (make, stderr=e, cwd=tmp_dir)
-    with open (path, "r") as e:
-        stderr = e.read ()
+    path = os.path.join(tmp_dir, "stderr.log")
+    with open(path, "w", encoding="UTF-8") as out_f:
+        status = subprocess.call(make, stderr=out_f, cwd=tmp_dir)
+    with open(path, "r", encoding="UTF-8") as in_f:
+        stderr = in_f.read()
     return tmp_dir, status, stderr
 
-def reassign_and_remove_dir (bug, tmp_dir):
-    if same_gcc_base_version:
-        print ("found {} {}".format (bug, deb_version))
+
+def reassign_and_remove_dir(bug: int, tmp_dir: str) -> None:
+    if SAME_GCC_BASE_VERSION:
+        print(f"found {bug} {deb_version}")
     else:
-        print ("reassign {} {} {}".format (bug, "gnat-" + new_version, deb_version))
-    shutil.rmtree (tmp_dir)
+        print(f"reassign {bug} gnat-{new_version} {deb_version}")
+    shutil.rmtree(tmp_dir)
 
-def report (bug, message, output):
-    print ("# {}: {}.".format (bug, message))
-    for line in output.split ("\n"):
-        print ("# " + line)
 
-def report_and_retitle (bug, message, output):
-    report (bug, message, output)
-    if same_gcc_base_version:
-        print ("fixed {} {}".format (bug, deb_version))
+def report(bug: int, message: str, output: str) -> None:
+    print(f"# {bug}: {message}.")
+    for report_line in output.split("\n"):
+        print(f"# {report_line}")
+
+
+def report_and_retitle(bug: int, message: str, output: str) -> None:
+    report(bug, message, output)
+    if SAME_GCC_BASE_VERSION:
+        print(f"fixed {bug} {deb_version}")
     else:
-        print ("retitle {} [Fixed in {}] <current title>".format (bug, new_version))
+        print(f"retitle {bug} [Fixed in {new_version}] <current title>")
 
-def check_compiles_but_should_not (bug, make, sources):
-    tmp_dir, status, stderr = attempt_to_reproduce (bug, make, sources)
+
+def check_compiles_but_should_not(bug: int,
+                                  make: Make,
+                                  sources: Sources,
+                                  ) -> None:
+    tmp_dir, status, stderr = attempt_to_reproduce(bug, make, sources)
     if status == 0:
-        reassign_and_remove_dir (bug, tmp_dir)
+        reassign_and_remove_dir(bug, tmp_dir)
     else:
-        report_and_retitle (bug, "now fails to compile (bug is fixed?)", stderr)
+        report_and_retitle(bug, "now fails to compile (bug is fixed?)", stderr)
 
-def check_reports_an_error_but_should_not (bug, make, sources, regex):
-    tmp_dir, status, stderr = attempt_to_reproduce (bug, make, sources)
+
+def check_reports_an_error_but_should_not(bug: int,
+                                          make: Make,
+                                          sources: Sources,
+                                          regex: str,
+                                          ) -> None:
+    tmp_dir, status, stderr = attempt_to_reproduce(bug, make, sources)
     if status == 0:
-        report_and_retitle (bug, "now compiles (bug is fixed?)", stderr)
-    elif re.search (regex, stderr):
-        reassign_and_remove_dir (bug, tmp_dir)
+        report_and_retitle(bug, "now compiles (bug is fixed?)", stderr)
+    elif re.search(regex, stderr):
+        reassign_and_remove_dir(bug, tmp_dir)
     else:
-        report (bug, "still fails to compile, but with a new stderr", stderr)
+        report(bug, "still fails to compile, but with a new stderr", stderr)
 
-def check_reports_error_but_forgets_one (bug, make, sources, regex):
-    tmp_dir, status, stderr = attempt_to_reproduce (bug, make, sources)
+
+def check_reports_error_but_forgets_one(bug: int,
+                                        make: Make,
+                                        sources: Sources,
+                                        regex: str,
+                                        ) -> None:
+    tmp_dir, status, stderr = attempt_to_reproduce(bug, make, sources)
     if status == 0:
-        report (bug, "now compiles (?)", stderr);
-    elif re.search (regex, stderr):
-        report_and_retitle (bug, "now reports the error (bug is fixed ?)", stderr)
+        report(bug, "now compiles (?)", stderr)
+    elif re.search(regex, stderr):
+        report_and_retitle(bug, "now reports the error (bug is fixed ?)",
+                           stderr)
     else:
-        reassign_and_remove_dir (bug, tmp_dir)
+        reassign_and_remove_dir(bug, tmp_dir)
 
-def check_produces_a_faulty_executable (bug, make, sources, regex, trigger):
-    tmp_dir, status, stderr = attempt_to_reproduce (bug, make, sources)
+
+def check_produces_a_faulty_executable(bug: int,
+                                       make: Make,
+                                       sources: Sources,
+                                       regex: str,
+                                       trigger: str,
+                                       ) -> None:
+    tmp_dir, status, stderr = attempt_to_reproduce(bug, make, sources)
     if status != 0:
-        report (bug, "cannot compile the trigger anymore", stderr)
+        report(bug, "cannot compile the trigger anymore", stderr)
     else:
-        output = subprocess.check_output ((os.path.join (tmp_dir, trigger),), cwd=tmp_dir).decode ()
-        if re.search (regex, output):
-            reassign_and_remove_dir (bug, tmp_dir)
+        output = subprocess.check_output((os.path.join(tmp_dir, trigger), ),
+                                         cwd=tmp_dir).decode()
+        if re.search(regex, output):
+            reassign_and_remove_dir(bug, tmp_dir)
         else:
-            report_and_retitle (bug, "output of the trigger changed (bug fixed?)", output)
+            report_and_retitle(bug,
+                               "output of the trigger changed (bug fixed?)",
+                               output)
+
 
 ######################################################################
 
-check_reports_an_error_but_should_not (
-    bug = 244936,
-    make = ("gnatmake", "p"),
-    regex = 'p\.ads:3:25: error: "foo" is hidden within declaration of instance',
-    sources = (
+check_reports_an_error_but_should_not(
+    bug=244936,
+    make=(f"gnatmake-{new_version}", "p"),
+    regex='p[.]ads:3:25: error: '
+    '"foo" is hidden within declaration of instance',
+    sources=(
         ("foo.ads", """generic
 procedure foo;
 """),
@@ -125,30 +171,11 @@ package p is
 end p;
 """)))
 
-check_compiles_but_should_not (
-    bug = 244970,
-    make = ("gnatmake", "pak5"),
-    sources = (
-        ("pak1.ads", """generic
-package pak1 is
-end pak1;
-"""),
-        ("pak1-pak2.ads", """generic
-package pak1.pak2 is
-end pak1.pak2;
-"""),
-        ("pak5.ads", """with pak1.pak2;
-generic
-   with package new_pak2 is new pak1.pak2;  -- ERROR: illegal use of pak1
-package pak5 is
-end pak5;
-""")))
-
-check_reports_an_error_but_should_not (
-    bug = 246187,
-    make = ("gnatmake", "test_43"),
-    regex = "Error detected at test_43.ads:11:4",
-    sources = (
+check_reports_an_error_but_should_not(
+    bug=246187,
+    make=(f"gnatmake-{new_version}", "test_43"),
+    regex="Error detected at test_43.ads:11:4",
+    sources=(
         ("test_43.ads", """package Test_43 is
   type T1 is private;
 
@@ -166,10 +193,10 @@ private
 end Test_43;
 """),))
 
-check_compiles_but_should_not (
-    bug = 247013,
-    make = ("gnatmake", "test_53"),
-    sources = (
+check_compiles_but_should_not(
+    bug=247013,
+    make=(f"gnatmake-{new_version}", "test_53"),
+    sources=(
         ("test_53.ads", """generic
    type T1 is private;
 package Test_53 is
@@ -177,10 +204,10 @@ package Test_53 is
 end Test_53;
 """),))
 
-check_compiles_but_should_not (
-    bug = 247017,
-    make = ("gnatmake", "test_59"),
-    sources = (
+check_compiles_but_should_not(
+    bug=247017,
+    make=(f"gnatmake-{new_version}", "test_59"),
+    sources=(
         ("test_59.adb", """procedure Test_59 is
 
     generic
@@ -198,10 +225,10 @@ begin
 end Test_59;
 """),))
 
-check_compiles_but_should_not (
-    bug = 247018,
-    make = ("gnatmake", "test_60"),
-    sources = (
+check_compiles_but_should_not(
+    bug=247018,
+    make=(f"gnatmake-{new_version}", "test_60"),
+    sources=(
         ("pak1.ads", """package pak1 is
    generic
    package pak2 is
@@ -214,10 +241,10 @@ package Test_60 is
 end Test_60;
 """)))
 
-check_compiles_but_should_not (
-    bug =  247019,
-    make = ("gnatmake", "test_61"),
-    sources = (
+check_compiles_but_should_not(
+    bug=247019,
+    make=(f"gnatmake-{new_version}", "test_61"),
+    sources=(
         ("test_61.adb", """procedure Test_61 is
    procedure p1;
 
@@ -233,12 +260,12 @@ begin
 end Test_61;
 """),))
 
-check_produces_a_faulty_executable (
-    bug = 247569,
-    make = ("gnatmake", "test_75"),
-    trigger = "test_75",
-    regex = "failed: wrong p1 called",
-    sources = (
+check_produces_a_faulty_executable(
+    bug=247569,
+    make=(f"gnatmake-{new_version}", "test_75"),
+    trigger="test_75",
+    regex="failed: wrong p1 called",
+    sources=(
         ("test_75.adb", """with text_io;
 procedure Test_75 is
    generic
@@ -279,10 +306,10 @@ begin
 end Test_75;
 """),))
 
-check_compiles_but_should_not (
-    bug = 247570,
-    make = ("gnatmake", "test_76"),
-    sources = (
+check_compiles_but_should_not(
+    bug=247570,
+    make=(f"gnatmake-{new_version}", "test_76"),
+    sources=(
         ("test_76.adb", """procedure Test_76 is
 
    generic
@@ -303,12 +330,12 @@ begin
 end Test_76;
 """),))
 
-check_produces_a_faulty_executable (
-    bug =  247571,
-    make = ("gnatmake", "test_77"),
-    trigger = "test_77",
-    regex = "failed: wrong p1 called",
-    sources = (
+check_produces_a_faulty_executable(
+    bug=247571,
+    make=(f"gnatmake-{new_version}", "test_77"),
+    trigger="test_77",
+    regex="failed: wrong p1 called",
+    sources=(
         ("pak.ads", """package pak is
    procedure p1;
    procedure p1(x: integer);
@@ -337,10 +364,10 @@ begin
 end Test_77;
 """)))
 
-check_compiles_but_should_not (
-    bug = 248166,
-    make = ("gnatmake", "test_82"),
-    sources = (
+check_compiles_but_should_not(
+    bug=248166,
+    make=(f"gnatmake-{new_version}", "test_82"),
+    sources=(
         ("test_82.adb", """procedure Test_82 is
    package pak1 is
       type T1 is tagged null record;
@@ -367,10 +394,10 @@ begin
 end Test_82;
 """),))
 
-check_compiles_but_should_not (
-    bug = 248168,
-    make = ("gnatmake", "test_84"),
-    sources = (
+check_compiles_but_should_not(
+    bug=248168,
+    make=(f"gnatmake-{new_version}", "test_84"),
+    sources=(
         ("test_84.adb", """procedure Test_84 is
    package pak1 is
       type T1 is abstract tagged null record;
@@ -395,10 +422,10 @@ begin
 end Test_84;
 """),))
 
-check_compiles_but_should_not (
-    bug = 248678,
-    make = ("gnatmake", "test_80"),
-    sources = (
+check_compiles_but_should_not(
+    bug=248678,
+    make=(f"gnatmake-{new_version}", "test_80"),
+    sources=(
         ("test_80.ads", """package Test_80 is
    generic
       type T1(<>) is private;
@@ -413,10 +440,10 @@ check_compiles_but_should_not (
 end Test_80;
 """),))
 
-check_compiles_but_should_not (
-    bug = 248681,
-    make = ("gnatmake", "test_91"),
-    sources = (
+check_compiles_but_should_not(
+    bug=248681,
+    make=(f"gnatmake-{new_version}", "test_91"),
+    sources=(
         ("test_91.adb", """--  RM 8.5.4(5)
 --  ...the convention of the renamed subprogram shall not be
 --  Intrinsic.
@@ -439,10 +466,10 @@ begin
 end Test_91;
 """),))
 
-check_compiles_but_should_not (
-    bug = 248682,
-    make = ("gnatmake", "main"),
-    sources = (
+check_compiles_but_should_not(
+    bug=248682,
+    make=(f"gnatmake-{new_version}", "main"),
+    sources=(
         ("main.adb", """--  RM 6.3.1(9)
 --  The default calling convention is Intrinsic for ...  an attribute
 --  that is a subprogram;
@@ -464,11 +491,11 @@ begin
 end;
 """),))
 
-check_reports_an_error_but_should_not (
-    bug = 253737,
-    make = ("gnatmake", "test_4"),
-    regex = 'test_4\.ads:3:01: error: "pak2" not declared in "pak1"',
-    sources = (
+check_reports_an_error_but_should_not(
+    bug=253737,
+    make=(f"gnatmake-{new_version}", "test_4"),
+    regex='test_4[.]ads:3:01: error: "pak2" not declared in "pak1"',
+    sources=(
         ("parent.ads", """generic
 package parent is
 end parent;
@@ -499,15 +526,17 @@ with pak6;
 package Test_4 is new pak6.pak4;
 """)))
 
-check_compiles_but_should_not (
-    bug = 269948,
-    make = ("gnatmake", "test_119"),
-    sources = (
-        ("test_119.ads", """--  RM 3.9.3/11 A generic actual subprogram shall not be an abstract
+check_compiles_but_should_not(
+    bug=269948,
+    make=(f"gnatmake-{new_version}", "test_119"),
+    sources=(
+        ("test_119.ads", """
+--  RM 3.9.3/11 A generic actual subprogram shall not be an abstract
 --  subprogram.  works OK if unrelated line (A) is commented out.
 package Test_119 is
    generic
-      with function "=" (X, Y : integer) return Boolean is <>;   -- Removing this allows GCC to detect the problem.
+      with function "=" (X, Y : integer) return Boolean is <>;
+      -- Removing this allows GCC to detect the problem.
    package pak1 is
       function "=" (X, Y: float) return Boolean is abstract;
       generic
@@ -521,10 +550,10 @@ package Test_119 is
 end Test_119;
 """),))
 
-check_compiles_but_should_not (
-    bug = 269951,
-    make = ("gnatmake", "test_118"),
-    sources = (
+check_compiles_but_should_not(
+    bug=269951,
+    make=(f"gnatmake-{new_version}", "test_118"),
+    sources=(
         ("pak1.ads", """generic
 package pak1 is
 end pak1;
@@ -548,12 +577,13 @@ end Test_118;
 """),))
 
 # As long as 24:14 is detected, it inhibits detection of 25:21.
-check_reports_error_but_forgets_one (
-    bug = 276224,
-    make = ("gnatmake", "test_121"),
-    regex = "test_121\.adb:25:21: dynamically tagged expression not allowed",
-    sources = (
-        ("test_121.adb", """--  If the expected type for an expression or name is some specific
+check_reports_error_but_forgets_one(
+    bug=276224,
+    make=(f"gnatmake-{new_version}", "test_121"),
+    regex="test_121[.]adb:25:21: dynamically tagged expression not allowed",
+    sources=(
+        ("test_121.adb",
+         """--  If the expected type for an expression or name is some specific
 --  tagged type, then the expression or name shall not be dynamically
 --  tagged unless it is a controlling operand in a call on a
 --  dispatching operation.
@@ -583,11 +613,12 @@ begin
 end Test_121;
 """),))
 
-check_reports_an_error_but_should_not (
-    bug = 276227,
-    make = ("gnatmake", "test_124"),
-    regex = 'test_124\.ads:6:35: error: size for "T_arr_constrained" too small, minimum allowed is 256',
-    sources = (
+check_reports_an_error_but_should_not(
+    bug=276227,
+    make=(f"gnatmake-{new_version}", "test_124"),
+    regex='test_124[.]ads:6:35: error: '
+    'size for "T_arr_constrained" too small, minimum allowed is 256',
+    sources=(
         ("test_124.ads", """package Test_124 is
    type T is range 1 .. 32;
    type T_arr_unconstrained is array (T range <>) of boolean;
@@ -597,12 +628,13 @@ check_reports_an_error_but_should_not (
 end Test_124;
 """),))
 
-check_reports_an_error_but_should_not (
-    bug = 278687,
-    make = ("gnatmake", "test_127"),
-    regex = 'test_127\.adb:10:21: error: expected type "T2" defined at line 4',
-    sources = (
-        ("test_127.ads", """-- The second parameter of T2'Class'Read is of type T2'Class,
+check_reports_an_error_but_should_not(
+    bug=278687,
+    make=(f"gnatmake-{new_version}", "test_127"),
+    regex='test_127[.]adb:10:21: error: expected type "T2" defined at line 4',
+    sources=(
+        ("test_127.ads",
+         """-- The second parameter of T2'Class'Read is of type T2'Class,
 -- which should match an object of type T3, which is derived
 -- from T2.
 package test_127 is
@@ -622,10 +654,10 @@ begin
 end test_127;
 """)))
 
-check_compiles_but_should_not (
-    bug = 278831,
-    make = ("gnatmake", "test_128"),
-    sources = (
+check_compiles_but_should_not(
+    bug=278831,
+    make=(f"gnatmake-{new_version}", "test_128"),
+    sources=(
         ("test_128.ads", """package Test_128 is
    package inner is
    private
@@ -642,12 +674,14 @@ end Test_128;
 """)))
 
 # Note that we also check the absence of the next inhibited message.
-check_reports_an_error_but_should_not (
-    bug = 279893,
-    make = ("gnatmake", "test_129"),
-    regex = 'test_129\.ads:13:49: error: designated type of actual does not match that of formal "T2"',
-    sources = (
-        ("pak1.ads", """-- legal instantiation rejected; illegal instantiation accepted
+check_reports_an_error_but_should_not(
+    bug=279893,
+    make=(f"gnatmake-{new_version}", "test_129"),
+    regex='test_129[.]ads:13:49: error: '
+    'designated type of actual does not match that of formal "T2"',
+    sources=(
+        ("pak1.ads",
+         """-- legal instantiation rejected; illegal instantiation accepted
 -- adapted from John Woodruff c.l.a. post
 
 generic
@@ -685,13 +719,14 @@ package Test_129 is
 end Test_129;
 """)))
 
-print ("# Please ignore the gnatlink message.")
-check_reports_an_error_but_should_not (
-    bug = 280939,
-    make = ("gnatmake", "test_130"),
-    regex = "test_130\.adb:.*: undefined reference to \`p2\'",
-    sources = (
-        ("pak1.ads", """--  RM 10.1.5(4) "the pragma shall have an argument that is a name
+print("# Please ignore the gnatlink message.")
+check_reports_an_error_but_should_not(
+    bug=280939,
+    make=(f"gnatmake-{new_version}", "test_130"),
+    regex="test_130[.]adb:.*: undefined reference to [`]p2\'",
+    sources=(
+        ("pak1.ads",
+         """--  RM 10.1.5(4) "the pragma shall have an argument that is a name
 --  denoting that declaration."
 --  RM 8.1(16) "The children of a parent library unit are inside the
 --  parent's declarative region."
@@ -712,11 +747,12 @@ begin
 end Test_130;
 """)))
 
-check_compiles_but_should_not (
-    bug = 283833,
-    make = ("gnatmake", "test_132"),
-    sources = (
-        ("pak1.ads", """-- RM 8.5.4(5)  the convention of the renamed subprogram shall not
+check_compiles_but_should_not(
+    bug=283833,
+    make=(f"gnatmake-{new_version}", "test_132"),
+    sources=(
+        ("pak1.ads",
+         """-- RM 8.5.4(5)  the convention of the renamed subprogram shall not
 -- be Intrinsic, if the renaming-as-body completes that declaration
 -- after the subprogram it declares is frozen.
 
@@ -747,10 +783,10 @@ end Test_132;
 end Test_132;
 """)))
 
-check_compiles_but_should_not (
-    bug = 283835,
-    make = ("gnatmake", "test_133"),
-    sources = (
+check_compiles_but_should_not(
+    bug=283835,
+    make=(f"gnatmake-{new_version}", "test_133"),
+    sources=(
         ("test_133.ads", """package Test_133 is
    package pak1 is
       type T1 is null record;
@@ -778,10 +814,10 @@ end Test_133;
 end test_133;
 """)))
 
-check_compiles_but_should_not (
-    bug = 416979,
-    make = ("gnatmake", "pak1"),
-    sources = (
+check_compiles_but_should_not(
+    bug=416979,
+    make=(f"gnatmake-{new_version}", "pak1"),
+    sources=(
         ("pak1.ads", """package pak1 is
    -- RM 7.3(13), 4.9.1(1)
    -- check that discriminants statically match
@@ -796,11 +832,12 @@ private
 end pak1;
 """),))
 
-check_reports_an_error_but_should_not (
-    bug = 660698,
-    make = ("gnatmake", "proc.adb"),
-    regex = 'proc\.adb:17:28: error: there is no applicable operator "And" for type "Standard\.Integer"',
-    sources = (
+check_reports_an_error_but_should_not(
+    bug=660698,
+    make=(f"gnatmake-{new_version}", "proc.adb"),
+    regex='proc[.]adb:17:28: error: '
+    'there is no applicable operator "And" for type "Standard[.]Integer"',
+    sources=(
         ("proc.adb", """procedure Proc is
    package P1 is
       type T is new Integer;
@@ -823,51 +860,12 @@ begin
 end Proc;
 """), ))
 
-# Even if an error is reported, the problem with the atomic variable
-# should be checked.
-check_reports_an_error_but_should_not (
-    bug = 643663,
-    make = ("gnatmake", "test"),
-    regex = 'test\.adb:4:25: error: no value supplied for component "Reserved"',
-    sources = (
-        ("pkg.ads", """package Pkg is
-   type Byte is mod 2**8;
-   type Reserved_24 is mod 2**24;
-
-   type Data_Record is
-      record
-         Data : Byte;
-         Reserved : Reserved_24;
-      end record;
-
-   for Data_Record use
-      record
-         Data at 0 range 0 .. 7;
-         Reserved at 0 range 8 .. 31;
-      end record;
-
-   for Data_Record'Size use 32;
-   for Data_Record'Alignment use 4;
-
-   Data_Register : Data_Record;
-   pragma Atomic (Data_Register);
-end Pkg;
-"""), ("test.adb", """with Pkg;
-procedure Test is
-begin
-   Pkg.Data_Register := (
-      Data => 255,
-      others => <> -- expected error: no value supplied for component "Reserved"
-   );
-end Test;
-""")))
-
-check_produces_a_faulty_executable (
-    bug = 864969,
-    make = ("gnatmake", "main"),
-    trigger = "main",
-    regex = "ZZund",
-    sources = (
+check_produces_a_faulty_executable(
+    bug=864969,
+    make=(f"gnatmake-{new_version}", "main"),
+    trigger="main",
+    regex="ZZund",
+    sources=(
         ("main.adb", """with Ada.Locales, Ada.Text_IO;
 procedure Main is
 begin
@@ -876,11 +874,11 @@ begin
 end Main;
 """),))
 
-check_produces_a_faulty_executable (
-    bug = 894225,
-    make = ("gnatmake", "main"),
-    trigger = "main",
-    sources = (
+check_produces_a_faulty_executable(
+    bug=894225,
+    make=(f"gnatmake-{new_version}", "main"),
+    trigger="main",
+    sources=(
         ("main.adb",
          """with Ada.Directories, Ada.Text_IO;
 procedure Main is
@@ -891,11 +889,11 @@ begin
 end Main;
 """),
     ),
-    regex = """^/a/b
+    regex="""^/a/b
 a/b
 b$""")
 
 try:
-    os.rmdir (workspace)
-except:
-    print ("Some unconfirmed, not removing directory {}.".format (workspace))
+    os.rmdir(workspace)
+except OSError:
+    print(f"Some unconfirmed, not removing directory {workspace}.")
